graft_snapshot() records the active schema build and latest committed
knowledge boundary of a Graft store. The returned value is serializable and
path-free: it contains no database connection, backend, or filesystem path.
graft_snapshot() records the active schema build and latest committed
knowledge boundary of a Graft store. The returned value is serializable and
path-free: it contains no database connection, backend, or filesystem path.